####################################################################################################################
# Code accompanying: Turn-taking between provisioning parents: partitioning alternation
# Authors: Davide Baldan, Camilla A. Hinde , Catherine M. Lessells
# Correspondence: D.Baldan@nioo.knaw.nl / dbaldan@unr.edu
####################################################################################################################


#### Simulation of turn-taking and Independent provisioning sequences ####

### these are the negative exponential distributions for the turn-taking and Independent provisioning sequences
set.seed(100)

# Turn-taking sequences have rate=2
a=rexp(1000,rate=2)
hist(a)
mean(a)
# Independent provisioning sequences have rate = 1
b=rexp(1000,rate=1)
hist(b)
mean(b)


# Express visits in seconds
a=a*60
hist(a)

b=b*60
hist(b)




####### 1 - CTH in turn-taking and Independent provisioning sequences ########

# 1.1 Simulation of 1000 sequences of turn-taking and calculation of turn-taking CTH
ttCTH <- vector(mode="numeric", length=0)

set.seed(100)

for(j in 1:1000) {
  
visits=rexp(1000,rate=2)
visit.time=cumsum(visits)
visits=visit.time*60
visits=round(visits, digits =0)
rm(visit.time)

# create 4hrs long sequences (14400 seconds)
visits= visits[visits< 14400]

# odd visits are male's ; even ones are female's
male= visits[seq(50) %% 2 == 1]
female= visits[seq(50) %% 2 == 0]



##### Calculation of correlated temporal heterogeneity
# Selection of the 20 time points
times= c(1:20)*11.42
times=times*60

# Creation of table for correlation
table=as.data.frame(matrix(data=NA, nrow=20, ncol=2))
names(table)=c("int.m", "int.f")

# Creation of male and female vectors
male=c(0,male,14400)
female=c(0,female,14400)

for(i in 1:20) {
  table[i,1] = male[which.max(male > times[i])] - male[(which.max(male > times[i])-1)]
  table[i,2] = female[which.max(female > times[i])] - female[(which.max(female > times[i])-1)]
}

table$int.m = 1/table$int.m
table$int.f = 1/table$int.f
ttCTH[j] <- cor(table$int.m, table$int.f)

}


hist(ttCTH)
boxplot(ttCTH)

mean(ttCTH)
sd(ttCTH)

histcthtt<-hist(ttCTH, plot=F,breaks=seq(-0.5,1,0.05))
histcthtt$counts <- histcthtt$counts / sum(histcthtt$counts)

plot(histcthtt, freq=TRUE,
     ylab="Relative Frequency",
     main="",  
     xlab="Correlated temporal heterogeneity in turn-taking sequences",
     col="grey70")






# 1.2 Simulation of Independent provisioning sequences and calculation of Independent provisioning CTH #


randomCTH <- vector(mode="numeric", length=0)
set.seed(100)

for(j in 1:1000) {

# Random male visits
visits=rexp(1000,rate=1)
visit.time=cumsum(visits)
visits=visit.time*60
visits=round(visits, digits =0)

rm(visit.time)
mvisits= visits[visits< 14400]

# random female visits
visits=rexp(1000,rate=1)
visit.time=cumsum(visits)
visits=visit.time*60
visits=round(visits, digits =0)

rm(visit.time)
fvisits= visits[visits< 14400]



# Selection of the 20 time points
times= c(1:20)*11.42
times=times*60

# Creation of table for correlation
table=as.data.frame(matrix(data=NA, nrow=20, ncol=2))
names(table)=c("int.m", "int.f")

# Creation of male and female vectors
male=c(0,mvisits,14400)

female=c(0,fvisits,14400)

for(i in 1:20) {
  table[i,1] = male[which.max(male > times[i])] - male[(which.max(male > times[i])-1)]
  table[i,2] = female[which.max(female > times[i])] - female[(which.max(female > times[i])-1)]
}

table$int.m = 1/table$int.m
table$int.f = 1/table$int.f
randomCTH[j] <- cor(table$int.m, table$int.f)

}

hist(randomCTH)
boxplot(randomCTH)

mean(randomCTH)
sd(randomCTH)

histcthrand<-hist(randomCTH, plot=F,breaks=seq(-0.5,1,0.05))
histcthrand$counts <- histcthrand$counts / sum(histcthrand$counts)

plot(histcthrand, freq=TRUE,
     ylab="Relative Frequency",
     main="",  
     xlab="Correlated temporal heterogeneity in random sequences",
     col="grey70")






# 1.3 Plot the two distribution of CTH values

par(mfrow=c(2,1),mai=c(1,1.2,.3,0.8))

plot(histcthrand, freq=TRUE,ylim=c(0,0.15),xlim=c(-0.5,1),
     ylab="Relative frequency",
     main="",  
     xlab="Provisioning CTH of independently provisioning pairs",
     col="grey70",xaxt="n",yaxt="n")

axis(1, at = seq(-0.5, 1, by = 0.25))
axis(2, at = seq(0, 0.15, by = 0.05))

plot(histcthtt, freq=TRUE,ylim=c(0,0.15),xlim=c(-0.5,1),
     ylab="Relative frequency",
     main="",  
     xlab="Provisioning CTH of turn-taking pairs",
     col="grey70", xaxt="n",yaxt="n")

axis(1, at = seq(-0.5, 1, by = 0.25))
axis(2, at = seq(0, 0.15, by = 0.05))







tiff("Fig3.tiff", width = 9, height = 7, units = 'in', res = 300) # size and resolution

{
  
  par(mfrow=c(2,1),mai=c(1,1.2,.3,0.8))
  
  plot(histcthrand, freq=TRUE,ylim=c(0,0.15),xlim=c(-0.5,1),
       ylab="Relative frequency",
       main="",  
       xlab="Provisioning CTH of independently provisioning pairs",
       col="grey70",xaxt="n",yaxt="n")
  
  axis(1, at = seq(-0.5, 1, by = 0.25))
  axis(2, at = seq(0, 0.15, by = 0.05))
  
  plot(histcthtt, freq=TRUE,ylim=c(0,0.15),xlim=c(-0.5,1),
       ylab="Relative frequency",
       main="",  
       xlab="Provisioning CTH of turn-taking pairs",
       col="grey70", xaxt="n",yaxt="n")
  
  axis(1, at = seq(-0.5, 1, by = 0.25))
  axis(2, at = seq(0, 0.15, by = 0.05))
  
  
}

dev.off()
















####### 2 - IVIs' histograms of turn-taking and Independent provisioning sequences ########

# 2.1 IVI'S HISTOGRAMS OF TURN-TAKING SEQUENCES #

# Simulation of 1000 sequences of turn-taking
ivis <- vector(mode="numeric", length=0)

set.seed(100)
for(j in 1:1000) {
  
  visits=rexp(1000,rate=2)
  visit.time=cumsum(visits)
  visits=visit.time*60
  visits=round(visits, digits =0)
  rm(visit.time)
  
  # create 4hrs long sequences (14400 seconds)
  visits= visits[visits< 14400]
  
  # odd visits are male's ; even ones are female's
  male= visits[seq(50) %% 2 == 1]
  female= visits[seq(50) %% 2 == 0]
  
  ivis=c(ivis,diff(male))
  ivis=c(ivis,diff(female))

  
}

mean(ivis)
sd(ivis)

hist(ivis, main="",  
     xlab="lenght inter-visit intervals in turn-taking sequences (s)")
table(ivis)

ivis400 = ivis[ivis<400]
table(ivis400)

## RELATIVE FREQUENCY HISTOGRAMS OF THE IVIS OF TURN-TAKING SEQUENCES ##

h<-hist(ivis400, plot=F,breaks=seq(0,400,10))
h$counts <- h$counts / sum(h$counts)

plot(h, freq=TRUE, ylab="Relative Frequency",
     main="",  
     xlab="Lenght inter-visit intervals in turn-taking sequences (s)",
     col="grey70")






# 2.1 IVI'S HISTOGRAMS OF Independent provisioning sequences #


ranivis <- vector(mode="numeric", length=0)

set.seed(100)

for(j in 1:1000) {
  
  # Random male visits
  visits=rexp(1000,rate=1)
  visit.time=cumsum(visits)
  visits=visit.time*60
  visits=round(visits, digits =0)
  
  rm(visit.time)
  mvisits= visits[visits< 14400]
  
  # random female visits
  visits=rexp(1000,rate=1)
  visit.time=cumsum(visits)
  visits=visit.time*60
  visits=round(visits, digits =0)
  
  rm(visit.time)
  fvisits= visits[visits< 14400]
  
  ranivis=c(ranivis,diff(mvisits))
  ranivis=c(ranivis,diff(fvisits))
  
}

mean(ranivis)
sd(ranivis)

hist(ranivis,breaks=seq(0,800,20))
table(ranivis)
ranivis400=  ranivis[ranivis<400]

# RELATIVE FREQUENCY HISTOGRAMS OF THE IVIS OF RANDOM SEQUENCES #

rh<-hist(ranivis400, plot=F,breaks=seq(0,400,10))
rh$counts <- rh$counts / sum(rh$counts)

plot(rh, freq=TRUE,
     ylab="Relative Frequency",
     main="",  
     xlab="Lenght inter-visit intervals in random sequences (s)",
     col="grey70")



# 2.3 Plot the two IVIs distributions

par(mfrow=c(2,1),mai=c(1,1.2,.5,0.8))

plot(rh, freq=TRUE,ylim=c(0,0.18),
     ylab="Relative frequency",
     main="",  
     xlab="Length of IVIs of independently provisioning parents (s)",
     col="grey70",xaxt="n",yaxt="n")
axis(1, at = seq(0, 400, by = 50))
axis(2, at = seq(0, 0.18, by = 0.06))


plot(h, freq=TRUE, ylim=c(0,0.18),
     ylab="Relative frequency",
     main="",  
     xlab="Length of IVIs of turn-taking parents (s)",
     col="grey70",xaxt="n", yaxt="n")
axis(1, at = seq(0, 400, by = 50))
axis(2, at = seq(0, 0.18, by = 0.06))





tiff("Fig2.tiff", width = 9, height = 7, units = 'in', res = 300) # size and resolution

{
  
  par(mfrow=c(2,1),mai=c(1,1.2,.3,0.8))
  
  plot(rh, freq=TRUE,ylim=c(0,0.18),
       ylab="Relative frequency",
       main="",  
       xlab="Length of IVIs of independently provisioning parents (s)",
       col="grey70",xaxt="n",yaxt="n")
  axis(1, at = seq(0, 400, by = 50))
  axis(2, at = seq(0, 0.18, by = 0.06))
  
  
  plot(h, freq=TRUE, ylim=c(0,0.18),
       ylab="Relative frequency",
       main="",  
       xlab="Length of IVIs of turn-taking parents (s)",
       col="grey70",xaxt="n", yaxt="n")
  axis(1, at = seq(0, 400, by = 50))
  axis(2, at = seq(0, 0.18, by = 0.06))
  
}

dev.off()












####### 3 - Alternation score in Independent provisioning sequences ########

alt=vector(mode="numeric", length=0)

set.seed(100)

for(i in 1:1000) {
  
  # Random male visits
  visits=rexp(1000,rate=1)
  visit.time=cumsum(visits)
  visits=visit.time*60
  visits=round(visits, digits =0)
  
  rm(visit.time)
  mvisits= visits[visits< 14400]
  
  # random female visits
  visits=rexp(1000,rate=1)
  visit.time=cumsum(visits)
  visits=visit.time*60
  visits=round(visits, digits =0)
  
  rm(visit.time)
  fvisits= visits[visits< 14400]
  
  male.seq= as.data.frame(mvisits)
  names(male.seq)=c("time")
  male.seq$sex= "m"
  
  female.seq= as.data.frame(fvisits)
  names(female.seq)=c("time")
  female.seq$sex= "f"
  
  # merging the two sequences into one dataset of visits
  sequence=rbind(male.seq,female.seq)
  sequence <- sequence[order(sequence$time),]
  
  
  
  
  sequence$visit=NA
  for(j in 2:length(sequence$visit)){
    
    if(sequence$sex[j-1]==sequence$sex[j]){
      sequence$visit[j] <- "nav"
    }
    
    if(sequence$sex[j-1] != sequence$sex[j]){
      sequence$visit[j] <- "av"
    }
    rm(j) 
  }  
  
  
  
  obs.table=matrix(0,nrow=3,ncol = 3)
  obs.m=sequence[sequence$sex == "m",]
  obs.f=sequence[sequence$sex == "f",]
  obs.table[1,1] = table(obs.m$visit)["nav"]
  obs.table[1,2] = table(obs.m$visit)["av"]
  obs.table[2,1] = table(obs.f$visit)["av"]
  obs.table[2,2] = table(obs.f$visit)["nav"]
  obs.table[1,3] = obs.table[1,1] + obs.table[1,2]
  obs.table[2,3] = obs.table[2,1] + obs.table[2,2]
  obs.table[3,1] = obs.table[1,1] + obs.table[2,1]
  obs.table[3,2] = obs.table[1,2] + obs.table[2,2]
  obs.table[3,3] = obs.table[1,3] + obs.table[2,3]
  
  rm(obs.m, obs.f)
  
  obs.alt.score=as.numeric(log(table(sequence$visit)["av"] / table(sequence$visit)["nav"]) - 
                             log((((obs.table[1,3] * obs.table[3,2])/obs.table[3,3]) + ((obs.table[2,3] * obs.table[3,1])/obs.table[3,3]))/
                                   (((obs.table[1,3] * obs.table[3,1])/obs.table[3,3]) + ((obs.table[2,3] * obs.table[3,2])/obs.table[3,3]))))
  
  alt[i] <- obs.alt.score
}

mean(alt)
sd(alt)


althist<-hist(alt, plot=F,breaks=seq(-0.4,0.4,0.05))
althist$counts <- althist$counts / sum(althist$counts)

plot(althist, freq=TRUE,
     ylab="Relative frequency",
     main="",  
     xlab="Alternation score of independently provisioning pairs",
     col="grey70",
     xaxt="n")

axis(1, at = seq(-0.4, 0.4, by = 0.1))




tiff("Fig1.tiff", width = 9, height = 7, units = 'in', res = 300) # size and resolution

{
  par(mar = c(5, 6.5, 3, 4))
  plot(althist, freq=TRUE,
       ylab="Relative frequency",
       main="",  
       xlab="Alternation score of independently provisioning pairs",
       col="grey70",
       xaxt="n")
  
  axis(1, at = seq(-0.4, 0.4, by = 0.1)) 
  
}

dev.off()
